% ==============================================================
% Domain Adaptation @ImageCLEF 2014
% Performance Evaluation Script
% Copyright (C) 2013-1014, Novi Patricia
% Contact author: novi.patricia@idiap.ch
% ==============================================================

fprintf('============================================\n');
fprintf('     Domain Adaptation @ImageCLEF 2014      \n');
fprintf('     Performance Evaluation Script          \n');
fprintf('============================================\n');
fprintf('\n\n');

clear all

% flag for checking the running program
isOctave = exist('OCTAVE_VERSION') ~= 0;

label_file = 'label.txt';      % Don't change this file
result_file = 'result.txt';     % Change this file name

% list class
classes = {'aeroplane'
        'bike'
        'bird'
        'boat'
        'bottle'
        'bus'
        'car'
        'dog'
        'horse'
        'monitor'
        'motorbike'
        'people'};

% number class
n_class = 12;

% number sample per class
n_sample = 50;

% init score
score = zeros(1,n_class);

% check file availability
if ~exist(label_file, 'file')
    fprintf('File ''%s'' is not exist!!!\n',label_file);
    fprintf('You need this file to run the script.\n');
    return
end
% open ground truth file
label = fopen(label_file,'r');
% read the first row
tlab = fgets(label);

% check file availability
if ~exist(result_file, 'file')
    fprintf('File ''%s'' is not exist!!!\n',result_file);
    fprintf('You need this file to run the script.\n');
    return
end
% open result file
res = fopen(result_file,'r');
% read the first row
tres = fgets(res);

fprintf('Counting the score \n');
% check each row of the result
while ischar(tres)    
    
    % split each row to number and class column
    pred = strsplit(tres,' ');
    truth = strsplit(tlab,' ');        
    
    % compare truth label with prediction
    if strcmp(cellstr(pred{2}),cellstr(truth{2}))
        % if prediction is equal with truth label
        % then increase score value
        
        % find index of current prediction, index = [1..12]
        if ~isOctave
            idx = strmatch(cellstr(pred{2}),classes,'exact');
        else
            % octave treats cell array differently from matlab
            % use strmatch in octave returns wrong result
            idx = find(strncmp(pred{2},classes,length(pred{2})-1)==1);
        end
        
        % get score of the idx-th
        curr_score = score(1,idx);
        % add score by 1
        score(1,idx) = curr_score + 1;
        
    end
    
    % go to next row
    tres = fgets(res);
    tlab = fgets(label);
end

% close files
fclose(res);
fclose(label);

% print out score for each class
fprintf('\n\nScore per class:\n');
for i=1:n_class
    fprintf('%d. %d \n',i,score(1,i));
end

% total score
score_tot = sum(score);

% print out total score
fprintf('\nTotal score:%d\n',score_tot);
